/*
 * GtkGLMaterialDialog
 * Copyright (C) 1999,2000  Rune Lillesveen
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "gtkglmaterialdialog.h"

static void print_material(GtkGLMaterial *mat)
{
  g_print("Ambient color  : (%f,%f,%f,%f)\n", mat->ambient[0], mat->ambient[1], mat->ambient[2], mat->ambient[3]);
  g_print("Diffuse color  : (%f,%f,%f,%f)\n", mat->diffuse[0], mat->diffuse[1], mat->diffuse[2], mat->diffuse[3]);
  g_print("Specular color : (%f,%f,%f,%f)\n", mat->specular[0], mat->specular[1], mat->specular[2], mat->specular[3]);
  g_print("Emissive color : (%f,%f,%f,%f)\n", mat->emission[0], mat->emission[1], mat->emission[2], mat->emission[3]);
  g_print("Shininess      : %f\n", mat->shininess);
}

static gint on_ok(GtkWidget *widget, gpointer data)
{
  GtkGLMaterialDialog *matdlg = GTK_GL_MATERIAL_DIALOG((GtkWidget*)data);
  g_print("OK clicked.\n");
  print_material(&matdlg->material);
  gtk_main_quit();
  return TRUE;
}

static gint on_cancel(GtkWidget *widget, gpointer data)
{
  g_print("Cancel clicked.\n");
  gtk_main_quit();
  return TRUE;
}

static gint on_destroy(GtkWidget *widget, gpointer data)
{
  g_print("Dialog destroyed.\n");
  gtk_main_quit();
  return TRUE;
}

int main(int argc, char **argv)
{
  GtkWidget *dlg;

  gtk_init(&argc, &argv);
  gdk_rgb_init();

  dlg = gtk_gl_material_dialog_new("Edit material");

  gtk_signal_connect(GTK_OBJECT(GTK_GL_MATERIAL_DIALOG(dlg)->ok_button), "clicked",
		     GTK_SIGNAL_FUNC(on_ok), (gpointer)dlg);

  gtk_signal_connect(GTK_OBJECT(GTK_GL_MATERIAL_DIALOG(dlg)->cancel_button), "clicked",
		     GTK_SIGNAL_FUNC(on_cancel), (gpointer)dlg);

  gtk_signal_connect(GTK_OBJECT(dlg), "destroy", GTK_SIGNAL_FUNC(on_destroy), NULL);

  gtk_widget_show(dlg);
  gtk_main();
  return 0;
}
